<?php
	require '../tmp/sql.php';
	require '../classes/mysql.php';
	
	$sql = new MySQL(); if ($sql->debug) error_reporting (E_ALL|E_STRICT); else error_reporting (0);
	
	require '../scripts/vendor/pqlite.php';
	require '../classes/settings.php';
	require '../classes/security.php';
	require '../classes/functions.php';
	require '../classes/template.php';
	require '../classes/player.php';
	require '../classes/stats.php';
	
	$secure = new Security();
	$settings = new Settings();
	$player = new Player();
	$tpl = new Templates();
	$tpl->load_phrases("admin", true);
	date_default_timezone_set($settings->get("settings_timezone"));
	
	
	
	### PLATOON-SYNCRONISATION ###
	// Check ob Platoon-Sync aktiviert ist
	if ($settings->get("update_platoon_sync_option")) {
		// Platoon-Sync ist aktiviert
		
		/* Check ob eine Syncronisation ansteht:
		   Wenn die Anzahl der Aufrufe dieser Updatefunktion grer/gleich der Syncronisationsfrequenz
		   ist, wird Syncronisiert. Ansonsten wird der Counter um 1 hochgesetzt */
		if ($settings->get("update_platoon_sync_count") >= $settings->get("update_platoon_sync_frequency")) {
			// Es steht eine Syncronisation an
			
			/* Check ob Platoons eingetragen wurden
			   Wenn nicht, geht es ohne weitere Aktion mit dem Update der Spieler weiter */
			$sql->query('SELECT * FROM '.$sql->prefix.'platoons ORDER BY platoonname');
			
			if ($sql->count()) {
				// Es wurden Platoons angegeben
				$settings->set("update_platoon_sync_count", "1", true); // Der Counter auf 1 zurckgesetzt
				$player_in_platoons = Array();  // Array fr alle Spielernamen aus allen Platoons
				$platform_of_players = Array(); // Array fr Plattformen der Spieler aus allen Platoons
				$player_in_database = Array();  // Array fr alle Spielernamen aus der Datenbank
				$message = Array(); // Array fr alle Aktionsmeldungen
				
				// Schleife durch alle angegebenen Platoons
				while ($row = $sql->fetchRow()) {
					if ($row['platoongame'] == "bf3") {
						// cURL-Abruf 
						$c=curl_init('http://battlelog.battlefield.com/bf3/platoon/'.$row['platoonid'].'/listmembers/');
						curl_setopt($c,CURLOPT_HEADER,false); curl_setopt($c,CURLOPT_HTTPHEADER,array('X-AjaxNavigation: 1')); curl_setopt($c,CURLOPT_RETURNTRANSFER,true);
						$result = json_decode(curl_exec($c));
						curl_close($c);
						
						// Array der Spieler des akuellen Platoons
						$players = $result->context->listMembers;
						
						// Check ob Battlelog berhaupt erreichbar ist
						if ($players === NULL) die("It seems that Battlelog is not available at the moment");
						
						// Alle Spielernamen und die Plattformen in die Arrays speichern
						foreach ($players as $playerobj) {
							if ($playerobj->membershipLevel >= 4) { // Membershiplevel: 2 (gelscht), 4 (Members), 128 (Leader), 256 (Founder)
								$player_in_platoons[] = $playerobj->persona->personaName;
								$platform_of_players[] = $row['platform'];
							}
						}
					} 
					
					else {
						// cURL-Abruf 
						$c=curl_init('http://battlelog.battlefield.com/bf4/platoons/members/'.$row['platoonid']);
						curl_setopt($c,CURLOPT_HEADER,false); curl_setopt($c,CURLOPT_HTTPHEADER,array('X-AjaxNavigation: 1')); curl_setopt($c,CURLOPT_RETURNTRANSFER,true);
						$result = json_decode(curl_exec($c));
						curl_close($c);
						
						// Spieler des Platoons
						$players = $result->context->club->members;
						if ($players === NULL) die("It seems that Battlelog is not available at the moment");
						
						foreach ($players as $p) {
							$player_in_platoons[]  = $p->user->username;
							$platform_of_players[] = $row['platform'];
						}
						
						// Leader des Platoons
						foreach ($result->context->club->leaders as $p) {
							$player_in_platoons[]  = $p->user->username;
							$platform_of_players[] = $row['platform'];
						}
						
						// Grnder des Platoons
						foreach ($result->context->club->founders as $p) {
							$player_in_platoons[]  = $p->user->username;
							$platform_of_players[] = $row['platform'];
						}
					}
				}
				
				// Spieler aus der Datenbank in das Array speichern
				$sql->query('SELECT id, name FROM '.$sql->prefix.'player ORDER BY name');
				while ($row = $sql->fetchRow()) $player_in_database[$row['id']] = $row['name'];
				
				// Spieler die im Platoon sind, aber nicht in der Datenbank, zu dieser hinzufgen
				for($i = 0; $i < count($player_in_platoons); $i++) {
					$name = $player_in_platoons[$i];
					$platform = $platform_of_players[$i];
					
					if (!in_array($name, $player_in_database)) {
						$message[] = $player->add($name, $platform, false);
					}
				}
				
				// Spieler, die in der Datenbank sind, aber in keinem Platoon, aus der DB lschen
				if ($settings->get("update_platoon_sync_option") == "2") {
					foreach ($player_in_database as $id => $name) {
						if (!in_array($name, $player_in_platoons)) {
							$message[] = $player->delete($id, $name);
						}
					}
				}
				
				// Ergebnis ausgeben
				if (isset ($_POST['request']) AND $_POST['request'] == "admin") {
					// Abruf aus dem Adminpanel heraus
					die (json_encode(array(
						"message" => $tpl->phrase('platoon_sync_complete')."<br/>".implode("<br/>", $message),
						"time" => date("d.m.Y - H:i", time())
					)));
				} 
				else {
					// Direkter Abruf
					eval ("\$html = \"".$tpl->template("update")."\";");
					$html = new PQLite($html);
					
					$html->find('ul')->appendHTML('<li>'.$tpl->phrase('platoon_sync_complete').'</li>');
					
					foreach ($message as $string) $html->find('ul')->appendHTML('<li>'.$string.'</li>');
					die ($html->getHTML());
				}
			}
		} 
		
		else {
			// Es steht keine Syncronisation an
			$count = $settings->get("update_platoon_sync_count");
			$settings->set("update_platoon_sync_count", $count+1, true); // Der Counter wird um 1 erhht
		}
	}
	
	
	
	### UPDATE OF THE PLAYERS ###
	$message = Array();
	$players = Array();
	$time = time();
	
	
	$sql->query('
		SELECT id, name, platform
		FROM '.$sql->prefix.'player
		ORDER BY date_stats_update ASC
		LIMIT '.$settings->get('update_player_per_update').'
	');
	
	while ($row = $sql->fetchRow()) {
		$players[] = $row;
	}
	
	
	foreach ($players as $array) {
		$result = $player->update($array['id'], $array['name'], $array['platform']);
		
		$sql->query('
			UPDATE `'.$sql->prefix.'player` SET
				`pushed`            = "'.$result['push'].'"
			WHERE `id` = "'.$array['id'].'"
		');
		
		$message[] = $array['name'].' ('.$result['api_player_status'].')';
	}
	
	
	$settings->set("update_date_last_refresh", $time, true);
	
	
	if (isset ($_POST['request']) AND $_POST['request'] == "admin") {
		die (json_encode(array(
			"message" => $tpl->phrase('update_message').implode("<br/>", $message),
			"time" => date("d.m.Y - H:i", $time)
		)));
	} 
	else {
		$func = new Functions();
		$preset = $func->load_settings("settings");
		
		eval ("\$html = \"".$tpl->template("update")."\";");
		$html   = new PQLite($html);
		
		foreach ($message as $string) $html->find('ul')->appendHTML('<li>'.$string.'</li>');
		echo $html->getHTML();
	}
?>